@@ -42,7 +42,7 @@ namespace MediaConch
                  watch_folder_recursive(true), create_policy_mode(false), file_information(false),
                  plugins_list_mode(false), list_watch_folders_mode(false), no_needs_files_mode(false)
     {
-        format = MediaConchLib::format_Text;
+        format = MediaConchLib::format_Simple;
     }
 
     //--------------------------------------------------------------------------
@@ -53,6 +53,12 @@ namespace MediaConch
     //--------------------------------------------------------------------------
     int CLI::init(std::string& err)
     {
+        if (format == MediaConchLib::format_CSV && !policies.size())
+        {
+            err = "CLI can use CSV format only with policies.";
+            return CLI_RETURN_ERROR;
+        }
+
         if (!no_needs_files_mode)
         {
             // If no filenames (and no options)
@@ -72,7 +78,7 @@ namespace MediaConch
             {
                 if (err == "MicroMediaTrace requires an XML output.")
                     err += " Add -fx.";
-                return -1;
+                return CLI_RETURN_ERROR;
             }
         }
 
@@ -80,10 +86,10 @@ namespace MediaConch
         MCL.set_plugins_configuration_file(plugins_configuration_file);
 
         if (MCL.init(err) < 0)
-            return -1;
+            return CLI_RETURN_ERROR;
 
         use_daemon = MCL.get_use_daemon();
-        return 0;
+        return CLI_RETURN_NONE;
     }
 
     //--------------------------------------------------------------------------
@@ -356,14 +362,18 @@ namespace MediaConch
     {
         if (f == "Text" || f == "text")
             return set_format(MediaConchLib::format_Text);
-        if (f == "XML" || f == "xml")
+        else if (f == "XML" || f == "xml")
             return set_format(MediaConchLib::format_Xml);
-        if (f == "MAXML" || f == "maxml")
+        else if (f == "MAXML" || f == "maxml")
             return set_format(MediaConchLib::format_MaXml);
-        if (f == "JSTREE" || f == "jstree")
+        else if (f == "JSTREE" || f == "jstree")
             return set_format(MediaConchLib::format_JsTree);
-        if (f == "HTML" || f == "html")
+        else if (f == "HTML" || f == "html")
             return set_format(MediaConchLib::format_Html);
+        else if (f == "SIMPLE" || f == "simple")
+            return set_format(MediaConchLib::format_Simple);
+        else if (f == "CSV" || f == "csv")
+            return set_format(MediaConchLib::format_CSV);
 
         return -1;
     }
@@ -605,10 +615,14 @@ namespace MediaConch
             if (res.tool)
                 report_kind = (MediaConchLib::report)*res.tool;
 
-            if (res.generated_id >= 0)
+            for (size_t i = 0; i < res.generated_id.size(); ++i)
             {
-                file_id = res.generated_id;
-                return is_ready(file_id, report_kind, err);
+                if (res.generated_id[i] == -1)
+                    continue;
+
+                file_id = res.generated_id[i];
+                if ((ret = is_ready(file_id, report_kind, err)) <= 0)
+                    return ret;
             }
         }
 
@@ -681,11 +695,21 @@ namespace MediaConch
         if (info->has_error)
             ss << "error_log:          " << std::boolalpha << info->error_log << "\n";
 
-        if (info->generated_id >= 0)
+        if (info->generated_id.size())
         {
-            std::string file;
-            MCL.checker_file_from_id(use_as_user, info->generated_id, file, error);
-            ss << "generated file:         " << file << "\n";
+            ss << "generated file:         [";
+            for (size_t i = 0; i < info->generated_id.size(); ++i)
+            {
+                if (i)
+                    ss << ",";
+
+                std::string file;
+                if (MCL.checker_file_from_id(use_as_user, info->generated_id[i], file, error) >= 0)
+                    ss << file;
+                else
+                    ss << i;
+            }
+            ss << "]\n";
         }
 
         if (info->source_id >= 0)
