@@ -68,14 +68,18 @@ int Help()
 
     TEXTOUT("Output Formats:");
     TEXTOUT("--Format=text -ft");
-    TEXTOUT("                    Output in Text format (default)");
+    TEXTOUT("                    Output MediaConch reports in Text format");
     TEXTOUT("--Format=xml -fx");
-    TEXTOUT("                    Output in MediaInfo/MediaConch/MediaTrace XML format");
+    TEXTOUT("                    Output MediaConch reports in XML format");
     TEXTOUT("                    (changed to -fa if there are more than 1 tool or more than 1 file)");
+    TEXTOUT("--Format=html -fh");
+    TEXTOUT("                    Output MediaConch reports in HTML format");
+    TEXTOUT("--Format=simple -fs");
+    TEXTOUT("                    Output MediaConch reports in a shorten form (>1 line only if there are errors), default format");
+    TEXTOUT("--Format=csv -fc");
+    TEXTOUT("                    Output MediaConch reports in CSV format (only for policies)");
     TEXTOUT("--Format=maxml -fa");
     TEXTOUT("                    Output in MediaArea XML format");
-    TEXTOUT("--Format=html -fh");
-    TEXTOUT("                    Output MediaConch report in HTML format");
     TEXTOUT("--Display=DisplayFileName, -d DisplayFileName");
     TEXTOUT("                    Apply the display transformation (XSL)");
     TEXTOUT("");
@@ -259,7 +263,7 @@ int Help_Xslt()
 //---------------------------------------------------------------------------
 int Version()
 {
-    TEXTOUT("MediaConch Command Line Interface 16.12");
+    TEXTOUT("MediaConch Command Line Interface 17.01.1");
 
     return CLI_RETURN_FINISH;
 }
