@@ -34,6 +34,8 @@
 #include "Common/generated/ImplementationReportDisplayTextUnicodeXsl.h"
 #endif //defined(_WIN32) || defined(WIN32)
 #include "Common/generated/ImplementationReportDisplayHtmlXsl.h"
+#include "Common/generated/ImplementationReportDisplaySimpleXsl.h"
+#include "Common/generated/ImplementationReportDisplayCSVXsl.h"
 #include "Common/generated/ImplementationReportMatroskaSchema.h"
 #include "Common/generated/MediaTraceDisplayTextXsl.h"
 #include "Common/generated/MediaTraceDisplayHtmlXsl.h"
@@ -408,8 +410,9 @@ long Core::checker_analyze(int user, const std::string& file, bool& registered,
     if (id < 0)
     {
         std::string file_last_modification = get_last_modification_file(file);
+        std::vector<long> generated_id;
         db_mutex.Enter();
-        id = get_db()->add_file(user, file, file_last_modification, options_str, err);
+        id = get_db()->add_file(user, file, file_last_modification, options_str, err, generated_id);
         db_mutex.Leave();
         if (id < 0)
             return -1;
@@ -438,12 +441,13 @@ long Core::checker_analyze(int user, const std::string& filename, long src_id, s
     if (force_analyze)
         analyzed = false;
 
+    std::vector<long> generated_id;
     std::string file_last_modification = get_last_modification_file(filename);
     if (id < 0)
     {
         db_mutex.Enter();
         id = get_db()->add_file(user, filename, file_last_modification, options_str, err,
-                                -1, src_id, generated_time,
+                                generated_id, src_id, generated_time,
                                 generated_log, generated_error_log);
         db_mutex.Leave();
         if (id < 0)
@@ -453,7 +457,7 @@ long Core::checker_analyze(int user, const std::string& filename, long src_id, s
     {
         db_mutex.Enter();
         id = get_db()->update_file(user, id, file_last_modification, options_str, err,
-                                   -1, src_id, generated_time,
+                                   generated_id, src_id, generated_time,
                                    generated_log, generated_error_log);
         db_mutex.Leave();
         if (id < 0)
@@ -467,10 +471,10 @@ long Core::checker_analyze(int user, const std::string& filename, long src_id, s
 }
 
 //---------------------------------------------------------------------------
-int Core::file_update_generated_file(int user, long src_id, long generated_id, std::string& err)
+int Core::file_add_generated_file(int user, long src_id, long generated_id, std::string& err)
 {
     db_mutex.Enter();
-    int ret = get_db()->update_file_generated_id(user, src_id, generated_id, err);
+    int ret = get_db()->add_file_generated_id(user, src_id, generated_id, err);
     db_mutex.Leave();
 
     return ret;
@@ -617,6 +621,10 @@ int Core::checker_get_report(int user, const std::bitset<MediaConchLib::report_M
             transform_with_xslt_text_memory(result->report, result->report);
         else if (f == MediaConchLib::format_Html)
             transform_with_xslt_html_memory(result->report, result->report);
+        else if (f == MediaConchLib::format_Simple)
+            transform_with_xslt_simple_memory(result->report, result->report);
+        else if (f == MediaConchLib::format_CSV)
+            transform_with_xslt_csv_memory(result->report, result->report);
     }
     else
     {
@@ -634,6 +642,8 @@ int Core::checker_get_report(int user, const std::bitset<MediaConchLib::report_M
             case MediaConchLib::format_MaXml:
             case MediaConchLib::format_Html:
             case MediaConchLib::format_OrigXml:
+            case MediaConchLib::format_Simple:
+            case MediaConchLib::format_CSV:
                 get_reports_output(user, files, options, f, report_set, result);
                 break;
             case MediaConchLib::format_JsTree:
@@ -686,7 +696,8 @@ int Core::checker_validate(int user, MediaConchLib::report report, const std::ve
         {
             //XXX
             std::string report;
-            res->valid = get_implementation_report(user, file_tmp, options, report);
+            if (get_implementation_report(user, files[i], options, report, res->valid, err) < 0)
+                return -1;
         }
         else if (report == MediaConchLib::report_MediaVeraPdf)
         {
@@ -894,6 +905,22 @@ int Core::transform_with_xslt_text_memory(const std::string& report, std::string
     return transform_with_xslt_memory(report, memory, opts, result);
 }
 
+//---------------------------------------------------------------------------
+int Core::transform_with_xslt_simple_memory(const std::string& report, std::string& result)
+{
+    std::map<std::string, std::string> opts;
+    std::string memory(implementation_report_display_simple_xsl);
+    return transform_with_xslt_memory(report, memory, opts, result);
+}
+
+//---------------------------------------------------------------------------
+int Core::transform_with_xslt_csv_memory(const std::string& report, std::string& result)
+{
+    std::map<std::string, std::string> opts;
+    std::string memory(implementation_report_display_csv_xsl);
+    return transform_with_xslt_memory(report, memory, opts, result);
+}
+
 //***************************************************************************
 // Policy validation
 //***************************************************************************
@@ -1209,7 +1236,7 @@ bool Core::file_is_existing(const std::string& filename)
 
 //---------------------------------------------------------------------------
 void Core::register_report_xml_to_database(int user, long file, const std::string& report,
-                                           MediaConchLib::report report_kind)
+                                           MediaConchLib::report report_kind, const std::string& options)
 {
     MediaConchLib::compression mode = compression_mode;
     std::string new_report(report);
@@ -1218,7 +1245,7 @@ void Core::register_report_xml_to_database(int user, long file, const std::strin
     std::string err;
     db_mutex.Enter();
     get_db()->save_report(user, file, report_kind, MediaConchLib::format_Xml,
-                          new_report, mode, true, err);
+                          options, new_report, mode, true, err);
     db_mutex.Leave();
 }
 
@@ -1235,7 +1262,7 @@ void Core::register_report_mediainfo_text_to_database(int user, long file, Media
     std::string err;
     db_mutex.Enter();
     get_db()->save_report(user, file, MediaConchLib::report_MediaInfo, MediaConchLib::format_Text,
-                          report, mode, true, err);
+                          "", report, mode, true, err);
     db_mutex.Leave();
 }
 
@@ -1251,7 +1278,7 @@ void Core::register_report_mediainfo_xml_to_database(int user, long file, MediaI
     std::string err;
     db_mutex.Enter();
     get_db()->save_report(user, file, MediaConchLib::report_MediaInfo, MediaConchLib::format_Xml,
-                    report, mode, true, err);
+                          "", report, mode, true, err);
     db_mutex.Leave();
 }
 
@@ -1286,7 +1313,7 @@ void Core::register_report_micromediatrace_xml_to_database(int user, long file,
     std::string err;
     db_mutex.Enter();
     get_db()->save_report(user, file, MediaConchLib::report_MicroMediaTrace, MediaConchLib::format_Xml,
-                          report, mode, true, err);
+                          "", report, mode, true, err);
     db_mutex.Leave();
 }
 
@@ -1326,10 +1353,11 @@ void Core::set_file_analyzed_to_database(int user, long id)
 
 //---------------------------------------------------------------------------
 void Core::register_reports_to_database(int user, long file, const std::string& report,
-                                        MediaConchLib::report report_kind, MediaInfoNameSpace::MediaInfo* curMI)
+                                        MediaConchLib::report report_kind, const std::string& options,
+                                        MediaInfoNameSpace::MediaInfo* curMI)
 {
     // Implementation
-    register_report_xml_to_database(user, file, report, report_kind);
+    register_report_xml_to_database(user, file, report, report_kind, options);
 
     //MI and MT
     register_reports_to_database(user, file, curMI);
@@ -1392,7 +1420,7 @@ void Core::create_report_mi_xml(int user, const std::vector<long>& files, std::s
         report += "<media ref=\"" + file + "\">\n";
 
         std::string info;
-        get_report_saved(user, vec, MediaConchLib::report_MediaInfo, MediaConchLib::format_Xml, info);
+        get_report_saved(user, vec, MediaConchLib::report_MediaInfo, MediaConchLib::format_Xml, "", info);
         get_content_of_media_in_xml(info);
         if (info.length())
             report += info;
@@ -1485,7 +1513,7 @@ void Core::create_report_mmt_xml(int user, const std::vector<long>& files, std::
         report += "<media ref=\"" + file + "\">";
 
         std::string trace;
-        get_report_saved(user, vec, MediaConchLib::report_MicroMediaTrace, MediaConchLib::format_Xml, trace);
+        get_report_saved(user, vec, MediaConchLib::report_MicroMediaTrace, MediaConchLib::format_Xml, "", trace);
         if (trace.length())
             report += trace;
         report += std::string("</media>");
@@ -1534,7 +1562,7 @@ void Core::create_report_ma_xml(int user, const std::vector<long>& files,
         if (reports[MediaConchLib::report_MediaInfo])
         {
             std::string info;
-            get_report_saved(user, vec, MediaConchLib::report_MediaInfo, MediaConchLib::format_Xml, info);
+            get_report_saved(user, vec, MediaConchLib::report_MediaInfo, MediaConchLib::format_Xml, "", info);
             get_content_of_media_in_xml(info);
             if (info.length())
                 report += "<MediaInfo xmlns=\"http" + (AcceptsHttps ? "s" : string()) + "://mediaarea.net/mediainfo\" version=\"2.0beta1\">" + info + "</MediaInfo>\n";
@@ -1555,7 +1583,7 @@ void Core::create_report_ma_xml(int user, const std::vector<long>& files,
         {
             std::string trace;
             get_report_saved(user, vec, MediaConchLib::report_MicroMediaTrace,
-                             MediaConchLib::format_Xml, trace);
+                             MediaConchLib::format_Xml, "", trace);
             report += "<MicroMediaTrace xmlns=\"http" + (AcceptsHttps ? "s" : string()) + "://mediaarea.net/micromediatrace\" version=\"0.1\">\n";
             if (trace.length())
                 report += trace;
@@ -1566,13 +1594,14 @@ void Core::create_report_ma_xml(int user, const std::vector<long>& files,
         if (reports[MediaConchLib::report_MediaConch])
         {
             std::string implem;
-            if (get_implementation_report(user, vec, options, implem))
-                get_content_of_media_in_xml(implem);
-            else
+            bool valid;
+            if (get_implementation_report(user, files[i], options, implem, valid, err) < 0)
                 implem = std::string();
+            else
+                get_content_of_media_in_xml(implem);
 
-            report += "<MediaConch xmlns=\"http" + (AcceptsHttps ? "s" : string()) + "://mediaarea.net/mediaconch\" version=\"0.2\">\n"
-                + implem + "</MediaConch>\n";
+            report += "<MediaConch xmlns=\"http" + (AcceptsHttps ? "s" : string()) +
+                "://mediaarea.net/mediaconch\" version=\"0.2\">\n" + implem + "</MediaConch>\n";
         }
         report += std::string("</media>\n");
     }
@@ -1584,7 +1613,7 @@ void Core::create_report_verapdf_xml(int user, const std::vector<long>& files, s
 {
     if (files.size() == 1)
     {
-        get_report_saved(user, files, MediaConchLib::report_MediaVeraPdf, MediaConchLib::format_Xml, report);
+        get_report_saved(user, files, MediaConchLib::report_MediaVeraPdf, MediaConchLib::format_Xml, "", report);
         return;
     }
     report = "Not implemented";
@@ -1595,7 +1624,7 @@ void Core::create_report_dpfmanager_xml(int user, const std::vector<long>& files
 {
     if (files.size() == 1)
     {
-        get_report_saved(user, files, MediaConchLib::report_MediaDpfManager, MediaConchLib::format_Xml, report);
+        get_report_saved(user, files, MediaConchLib::report_MediaDpfManager, MediaConchLib::format_Xml, "", report);
         return;
     }
     report = "Not implemented";
@@ -1604,16 +1633,17 @@ void Core::create_report_dpfmanager_xml(int user, const std::vector<long>& files
 //---------------------------------------------------------------------------
 void Core::get_report_saved(int user, const std::vector<long>& files,
                             MediaConchLib::report reportKind, MediaConchLib::format f,
-                            std::string& report)
+                            const std::string& options, std::string& report)
 {
     if (f == MediaConchLib::format_MaXml)
     {
-        std::map<std::string, std::string> options;
-        create_report_ma_xml(user, files, options, report, get_bitset_with_mi_mt());
+        std::map<std::string, std::string> map_options;
+        create_report_ma_xml(user, files, map_options, report, get_bitset_with_mi_mt());
         return;
     }
 
-    if (reportKind != MediaConchLib::report_MediaInfo && reportKind != MediaConchLib::report_MicroMediaTrace
+    if (reportKind != MediaConchLib::report_MediaConch &&
+        reportKind != MediaConchLib::report_MediaInfo && reportKind != MediaConchLib::report_MicroMediaTrace
         && reportKind != MediaConchLib::report_MediaVeraPdf && reportKind != MediaConchLib::report_MediaDpfManager)
         return;
 
@@ -1623,10 +1653,10 @@ void Core::get_report_saved(int user, const std::vector<long>& files,
     for (size_t i = 0; i < files.size(); ++i)
     {
         std::string raw;
-        MediaConchLib::compression compress;
+        MediaConchLib::compression compress = MediaConchLib::compression_None;
         std::string err;
         db_mutex.Enter();
-        get_db()->get_report(user, files[i], reportKind, f, raw, compress, err);
+        get_db()->get_report(user, files[i], reportKind, f, options, raw, compress, err);
         db_mutex.Leave();
         uncompress_report(raw, compress);
         report += raw;
@@ -1652,7 +1682,7 @@ void Core::get_reports_output(int user, const std::vector<long>& files,
             if (f == MediaConchLib::format_Xml)
                 create_report_mi_xml(user, files, result->report);
             else
-                get_report_saved(user, files, MediaConchLib::report_MediaInfo, f, result->report);
+                get_report_saved(user, files, MediaConchLib::report_MediaInfo, f, "", result->report);
             result->report += "\r\n";
         }
 
@@ -1692,7 +1722,10 @@ void Core::get_reports_output(int user, const std::vector<long>& files,
         if (report_set[MediaConchLib::report_MediaConch])
         {
             std::string tmp;
-            bool is_valid = get_implementation_report(user, files, options, tmp);
+            std::string err;
+            bool is_valid = false;
+            if (get_implementation_reports(user, files, options, tmp, is_valid, err) < 0)
+                tmp = std::string();
 
             if (f == MediaConchLib::format_Html)
                 transform_with_xslt_html_memory(tmp, tmp);
@@ -1700,6 +1733,10 @@ void Core::get_reports_output(int user, const std::vector<long>& files,
             {
                 // No transformation for XML
             }
+            else if (f == MediaConchLib::format_Simple)
+                transform_with_xslt_simple_memory(tmp, tmp);
+            else if (f == MediaConchLib::format_CSV)
+                transform_with_xslt_csv_memory(tmp, tmp);
             else
                 transform_with_xslt_text_memory(tmp, tmp);
 
@@ -1740,6 +1777,10 @@ void Core::get_reports_output(int user, const std::vector<long>& files,
             {
                 if (f == MediaConchLib::format_Html)
                     transform_with_xslt_html_memory(transformed, transformed);
+                else if (f == MediaConchLib::format_Simple)
+                    transform_with_xslt_simple_memory(transformed, transformed);
+                else if (f == MediaConchLib::format_CSV)
+                    transform_with_xslt_csv_memory(transformed, transformed);
                 else
                     transform_with_xslt_text_memory(transformed, transformed);
 
@@ -1776,6 +1817,10 @@ void Core::get_reports_output(int user, const std::vector<long>& files,
             {
                 if (f == MediaConchLib::format_Html)
                     transform_with_xslt_html_memory(transformed, transformed);
+                if (f == MediaConchLib::format_Simple)
+                    transform_with_xslt_simple_memory(transformed, transformed);
+                else if (f == MediaConchLib::format_CSV)
+                    transform_with_xslt_csv_memory(transformed, transformed);
                 else
                     transform_with_xslt_text_memory(transformed, transformed);
 
@@ -1787,17 +1832,88 @@ void Core::get_reports_output(int user, const std::vector<long>& files,
 }
 
 //---------------------------------------------------------------------------
-bool Core::get_implementation_report(int user, const std::vector<long>& files,
+int Core::get_implementation_reports(int user, const std::vector<long>& files,
                                      const std::map<std::string, std::string>& options,
-                                     std::string& report)
+                                     std::string& report, bool& valid, std::string& err)
 {
-    std::string memory(implementation_report_xsl);
-    std::string r;
-    bool valid = validate_xslt_from_memory(user, files, options, memory, r, true);
+    bool AcceptsHttps = accepts_https();
+    valid = true;
+
+    std::stringstream verbo;
+    std::map<std::string, std::string>::const_iterator it = options.find("verbosity");
+    if (it != options.end() && it->second.size())
+        verbo << it->second;
+    else
+        verbo << "5";
+
+    report = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
+    report += "<MediaConch xmlns=\"http" + (AcceptsHttps ? "s" : string()) +
+        "://mediaarea.net/mediaconch\" version=\"0.2\" verbosity=\"" + verbo.str() + "\">\n";
+    for (size_t i = 0; i < files.size(); ++i)
+    {
+        std::string file;
+        checker_file_from_id(user, files[i], file, err);
+        xml_escape_attributes(file);
+
+        report += "  <media ref=\"" + file + "\">";
+        std::string implem;
+        bool v = false;
+        if (get_implementation_report(user, files[i], options, implem, v, err) < 0)
+            implem = std::string();
+        else
+            get_content_of_media_in_xml(implem);
+
+        report += implem + "</media>\n";
+
+        if (!v)
+            valid = false;
+    }
+
+    report += "</MediaConch>\n";
+
+    return 0;
+}
+
+//---------------------------------------------------------------------------
+int Core::get_implementation_report(int user, long file, const std::map<std::string, std::string>& options,
+                                    std::string& report, bool& valid, std::string& err)
+{
+    std::string options_str = serialize_string_from_options_map(options);
+    valid = true;
+    std::string tmp_report;
+
+    db_mutex.Enter();
+    bool registered = get_db()->report_is_registered(user, file, MediaConchLib::report_MediaConch, MediaConchLib::format_Xml, options_str, err);
+    db_mutex.Leave();
+    if (!registered)
+    {
+        std::string memory(implementation_report_xsl);
+        std::vector<long> tocheck;
+        tocheck.push_back(file);
+        valid = validate_xslt_from_memory(user, tocheck, options, memory, tmp_report, true);
+
+        MediaConchLib::compression mode = compression_mode;
+        compress_report(tmp_report, mode);
+
+        db_mutex.Enter();
+        get_db()->save_report(user, file, MediaConchLib::report_MediaConch, MediaConchLib::format_Xml,
+                              options_str, tmp_report, mode, 0, err);
+        db_mutex.Leave();
+        tmp_report = std::string();
+    }
+
+    MediaConchLib::compression compress = MediaConchLib::compression_None;
+    db_mutex.Enter();
+    get_db()->get_report(user, file, MediaConchLib::report_MediaConch, MediaConchLib::format_Xml,
+                         options_str, tmp_report, compress, err);
+    db_mutex.Leave();
+
+    uncompress_report(tmp_report, compress);
     if (valid)
-        valid = implementation_is_valid(r);
-    report += r;
-    return valid;
+        valid = implementation_is_valid(tmp_report);
+    report += tmp_report;
+
+    return 0;
 }
 
 //---------------------------------------------------------------------------
@@ -1807,7 +1923,7 @@ bool Core::get_verapdf_report(int user, long file, std::string& report)
     files.push_back(file);
 
     get_report_saved(user, files, MediaConchLib::report_MediaVeraPdf, MediaConchLib::format_Xml,
-                     report);
+                     "", report);
 
     return verapdf_report_is_valid(report);
 }
@@ -1819,7 +1935,7 @@ bool Core::get_dpfmanager_report(int user, long file, std::string& report)
     files.push_back(file);
 
     get_report_saved(user, files, MediaConchLib::report_MediaDpfManager, MediaConchLib::format_Xml,
-                     report);
+                     "", report);
 
     return dpfmanager_report_is_valid(report);
 }
@@ -1956,6 +2072,54 @@ std::vector<std::pair<std::string,std::string> > Core::parse_options_vec_from_st
     return toreturn;
 }
 
+//---------------------------------------------------------------------------
+std::string Core::serialize_string_from_options_map(const std::map<std::string,std::string>& options)
+{
+    std::stringstream toreturn;
+
+    std::map<std::string,std::string>::const_iterator it = options.begin();
+    for (; it != options.end(); ++it)
+        toreturn << it->first.size() << "," << it->first << it->second.size() << "," << it->second;
+
+    return toreturn.str();
+}
+
+//---------------------------------------------------------------------------
+std::map<std::string, std::string> Core::parse_options_map_from_string(const std::string& options)
+{
+    std::map<std::string, std::string> toreturn;
+
+    size_t pos = 0;
+    size_t start;
+
+    std::vector<std::string> opt;
+    while (pos != std::string::npos)
+    {
+        start = pos;
+        pos = options.find(",", start);
+        if (pos == std::string::npos)
+            continue;
+
+        std::string size = options.substr(start, pos - start);
+        pos += 1;
+        char *end = NULL;
+        long len = strtol(size.c_str(), &end, 10);
+        if (len < 0 || pos + len > options.size())
+        {
+            pos = std::string::npos;
+            continue;
+        }
+
+        opt.push_back(options.substr(pos, len));
+        pos += len;
+    }
+
+    for (size_t i = 0; i + 1 < opt.size(); i += 2)
+        toreturn[opt[i]] = opt[i + 1];
+
+    return toreturn;
+}
+
 //---------------------------------------------------------------------------
 std::string Core::get_local_config_path()
 {
@@ -2288,18 +2452,28 @@ bool Core::policy_is_valid(const std::string& report)
 //---------------------------------------------------------------------------
 bool Core::verapdf_report_is_valid(const std::string& report)
 {
-    size_t pos = report.find(" compliant=\"false\"");
-    if (pos != std::string::npos)
+    size_t pos = report.find("<summary");
+    if (pos == std::string::npos)
+        return true;
+
+    std::string invalid("inValid=\"");
+    pos = report.find(invalid, pos);
+    if (pos == std::string::npos)
+        return true;
+
+    if (report.size() > pos + invalid.size() && report[pos + invalid.size()] != '0')
         return false;
+
     return true;
 }
 
 //---------------------------------------------------------------------------
 bool Core::dpfmanager_report_is_valid(const std::string& report)
 {
-    size_t pos = report.find("<invalid_files>1</invalid_files>");
+    size_t pos = report.find("<level>error</level>");
     if (pos != std::string::npos)
         return false;
+
     return true;
 }
 
