@@ -67,6 +67,8 @@ public:
         format_JsTree,
         format_Html,
         format_OrigXml,
+        format_Simple,
+        format_CSV,
         format_Max,
     };
 
@@ -99,19 +101,19 @@ public:
 
     struct Checker_StatusRes
     {
-        Checker_StatusRes() : id(-1), finished(false), has_error(false), percent(NULL), tool(NULL), generated_id(-1), source_id(-1) {}
+        Checker_StatusRes() : id(-1), finished(false), has_error(false), percent(NULL), tool(NULL), source_id(-1) {}
 
-        long         id;
-        bool         finished;
+        long               id;
+        bool               finished;
 
-        bool         has_error;
-        std::string  error_log;
+        bool               has_error;
+        std::string        error_log;
 
-        double      *percent;
+        double            *percent;
 
-        int         *tool;
-        long         generated_id;
-        long         source_id;
+        int               *tool;
+        std::vector<long>  generated_id;
+        long               source_id;
     };
 
     struct Checker_ReportRes
@@ -131,14 +133,14 @@ public:
 
     struct Checker_FileInfo
     {
-        Checker_FileInfo() : generated_id(-1), source_id(-1), generated_time((size_t)-1), analyzed(false), has_error(false) {}
+        Checker_FileInfo() : source_id(-1), generated_time((size_t)-1), analyzed(false), has_error(false) {}
 
         std::string                                      filename;
         std::string                                      file_last_modification;
         std::string                                      generated_log;
         std::string                                      generated_error_log;
         std::vector<std::pair<std::string,std::string> > options;
-        long                                             generated_id;
+        std::vector<long>                                generated_id;
         long                                             source_id;
         size_t                                           generated_time;
         bool                                             analyzed;
@@ -247,6 +249,8 @@ public:
     static const std::string display_text_name;
     static const std::string display_html_name;
     static const std::string display_jstree_name;
+    static const std::string display_simple_name;
+    static const std::string display_csv_name;
 
     // General
     int  init(std::string& err);
