@@ -27,7 +27,7 @@ namespace MediaConch {
 // SQLLiteReport
 //***************************************************************************
 
-int SQLLiteReport::current_report_version = 5;
+int SQLLiteReport::current_report_version = 7;
 
 //***************************************************************************
 // Constructor/Destructor
@@ -118,6 +118,8 @@ int SQLLiteReport::update_report_table()
     UPDATE_REPORT_TABLE_FOR_VERSION(2);
     UPDATE_REPORT_TABLE_FOR_VERSION(3);
     UPDATE_REPORT_TABLE_FOR_VERSION(4);
+    UPDATE_REPORT_TABLE_FOR_VERSION(5);
+    UPDATE_REPORT_TABLE_FOR_VERSION(6);
 
 #undef UPDATE_REPORT_TABLE_FOR_VERSION
 
@@ -148,15 +150,11 @@ void SQLLiteReport::get_users_id(std::vector<long>& ids, std::string& err)
 
 long SQLLiteReport::add_file(int user, const std::string& filename, const std::string& file_last_modification,
                              const std::string& options, std::string& err,
-                             long generated_id,
+                             const std::vector<long>& generated_id,
                              long source_id, size_t generated_time,
                              const std::string& generated_log, const std::string& generated_error_log)
 {
-    std::string opt = options;
-    if (!opt.size())
-        opt = "";
-
-    long id = get_file_id(user, filename, file_last_modification, opt, err);
+    long id = get_file_id(user, filename, file_last_modification, options, err);
     if (id >= 0)
         return id;
 
@@ -194,7 +192,9 @@ long SQLLiteReport::add_file(int user, const std::string& filename, const std::s
         return -1;
     }
 
-    ret = sqlite3_bind_int(stmt, 4, generated_id);
+    std::string g_id;
+    longs_to_string(generated_id, g_id);
+    ret = sqlite3_bind_blob(stmt, 4, g_id.c_str(), g_id.size(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
@@ -229,7 +229,7 @@ long SQLLiteReport::add_file(int user, const std::string& filename, const std::s
         return -1;
     }
 
-    ret = sqlite3_bind_blob(stmt, 9, opt.c_str(), opt.length(), SQLITE_STATIC);
+    ret = sqlite3_bind_text(stmt, 9, options.c_str(), options.size(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
@@ -242,13 +242,13 @@ long SQLLiteReport::add_file(int user, const std::string& filename, const std::s
         return -1;
     }
 
-    id = get_file_id(user, filename, file_last_modification, opt, err);
+    id = get_file_id(user, filename, file_last_modification, options, err);
     return id;
 }
 
 long SQLLiteReport::update_file(int user, long file_id, const std::string& file_last_modification,
                                 const std::string& options, std::string& err,
-                                long generated_id, long source_id, size_t generated_time,
+                                const std::vector<long>& generated_id, long source_id, size_t generated_time,
                                 const std::string& generated_log, const std::string& generated_error_log)
 {
     std::stringstream create;
@@ -271,7 +271,9 @@ long SQLLiteReport::update_file(int user, long file_id, const std::string& file_
         return -1;
     }
 
-    ret = sqlite3_bind_int(stmt, 2, generated_id);
+    std::string g_id;
+    longs_to_string(generated_id, g_id);
+    ret = sqlite3_bind_blob(stmt, 2, g_id.c_str(), g_id.size(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
@@ -320,7 +322,7 @@ long SQLLiteReport::update_file(int user, long file_id, const std::string& file_
         return -1;
     }
 
-    ret = sqlite3_bind_blob(stmt, 9, options.c_str(), options.length(), SQLITE_STATIC);
+    ret = sqlite3_bind_text(stmt, 9, options.c_str(), options.size(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
@@ -369,11 +371,7 @@ long SQLLiteReport::get_file_id(int user, const std::string& filename, const std
         return -1;
     }
 
-    std::string opt = options;
-    if (!opt.size())
-        opt = "";
-
-    ret = sqlite3_bind_blob(stmt, 3, opt.c_str(), opt.length(), SQLITE_STATIC);
+    ret = sqlite3_bind_text(stmt, 3, options.c_str(), options.size(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
@@ -444,10 +442,10 @@ int SQLLiteReport::get_file_name_from_id(int user, long id, std::string& file, s
 }
 
 int SQLLiteReport::get_file_information_from_id(int user, long id, std::string& filename, std::string& file_last_modification,
-                                                 long& generated_id, long& source_id, size_t& generated_time,
-                                                 std::string& generated_log, std::string& generated_error_log,
-                                                 std::string& options, bool& analyzed,
-                                                 bool& has_error, std::string& error_log, std::string& err)
+                                                std::vector<long>& generated_id, long& source_id, size_t& generated_time,
+                                                std::string& generated_log, std::string& generated_error_log,
+                                                std::string& options, bool& analyzed,
+                                                bool& has_error, std::string& error_log, std::string& err)
 {
     std::stringstream create;
     std::string name("FILENAME");
@@ -514,7 +512,10 @@ int SQLLiteReport::get_file_information_from_id(int user, long id, std::string&
         analyzed = (bool)std_string_to_int(reports[0][analyz]);
 
     if (reports[0].find(gen_id) != reports[0].end())
-        generated_id = std_string_to_int(reports[0][gen_id]);
+    {
+        std::string g_id;
+        string_to_longs(reports[0][gen_id], generated_id);
+    }
 
     if (reports[0].find(src_id) != reports[0].end())
         source_id = std_string_to_int(reports[0][src_id]);
@@ -540,8 +541,59 @@ int SQLLiteReport::get_file_information_from_id(int user, long id, std::string&
     return 0;
 }
 
-int SQLLiteReport::update_file_generated_id(int user, long source_id, long generated_id, std::string& err)
+int SQLLiteReport::get_generated_id(int user, long id, std::vector<long>& generated_id, std::string& err)
 {
+    std::stringstream create;
+    std::string gen_id("GENERATED_ID");
+
+    reports.clear();
+    create << "SELECT " << gen_id;
+    create << " FROM MEDIACONCH_FILE";
+    create << " WHERE ID = ? AND USER = ?;";
+    query = create.str();
+
+    if (prepare_v2(query, err) < 0)
+        return -1;
+
+    int ret = sqlite3_bind_int(stmt, 1, id);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
+
+    ret = sqlite3_bind_int(stmt, 2, user);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
+
+    if (execute())
+    {
+        err = error;
+        return -1;
+    }
+
+    if (reports.size() != 1)
+        return 0;
+
+    if (reports[0].find(gen_id) != reports[0].end())
+    {
+        std::string g_id;
+        string_to_longs(reports[0][gen_id], generated_id);
+    }
+
+    return 0;
+}
+
+int SQLLiteReport::add_file_generated_id(int user, long source_id, long generated_id, std::string& err)
+{
+    std::vector<long> ids;
+    if (get_generated_id(user, source_id, ids, err))
+        return -1;
+    ids.push_back(generated_id);
+
     std::stringstream create;
 
     reports.clear();
@@ -553,7 +605,9 @@ int SQLLiteReport::update_file_generated_id(int user, long source_id, long gener
     if (prepare_v2(query, err) < 0)
         return -1;
 
-    int ret = sqlite3_bind_int(stmt, 1, generated_id);
+    std::string g_id;
+    longs_to_string(ids, g_id);
+    int ret = sqlite3_bind_blob(stmt, 1, g_id.c_str(), g_id.size(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
@@ -731,7 +785,8 @@ bool SQLLiteReport::file_is_analyzed(int user, long id, std::string& err)
     return true;
 }
 
-int SQLLiteReport::save_report(int user, long file_id, MediaConchLib::report reportKind, MediaConchLib::format format,
+int SQLLiteReport::save_report(int user, long file_id, MediaConchLib::report report_kind, MediaConchLib::format format,
+                               const std::string& options,
                                const std::string& report, MediaConchLib::compression compress,
                                int mil_version, std::string& err)
 {
@@ -743,13 +798,13 @@ int SQLLiteReport::save_report(int user, long file_id, MediaConchLib::report rep
         return -1;
     }
 
-    if (report_is_registered(user, file_id, reportKind, format, err))
-        return update_report(user, file_id, reportKind, format, report, compress, mil_version, err);
+    if (report_is_registered(user, file_id, report_kind, format, options, err))
+        return update_report(user, file_id, report_kind, format, options, report, compress, mil_version, err);
 
     reports.clear();
     create << "INSERT INTO MEDIACONCH_REPORT";
-    create << " (FILE_ID, TOOL, FORMAT, REPORT, COMPRESS, MIL_VERSION)";
-    create << " VALUES (?, ?, ?, ?, ?, ?);";
+    create << " (FILE_ID, TOOL, FORMAT, OPTIONS, REPORT, COMPRESS, MIL_VERSION)";
+    create << " VALUES (?, ?, ?, ?, ?, ?, ?);";
     query = create.str();
 
     if (prepare_v2(query, err) < 0)
@@ -762,7 +817,7 @@ int SQLLiteReport::save_report(int user, long file_id, MediaConchLib::report rep
         return -1;
     }
 
-    ret = sqlite3_bind_int(stmt, 2, (int)reportKind);
+    ret = sqlite3_bind_int(stmt, 2, (int)report_kind);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
@@ -776,21 +831,28 @@ int SQLLiteReport::save_report(int user, long file_id, MediaConchLib::report rep
         return -1;
     }
 
-    ret = sqlite3_bind_blob(stmt, 4, report.c_str(), report.length(), SQLITE_STATIC);
+    ret = sqlite3_bind_text(stmt, 4, options.c_str(), options.size(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
         return -1;
     }
 
-    ret = sqlite3_bind_int(stmt, 5, (int)compress);
+    ret = sqlite3_bind_blob(stmt, 5, report.c_str(), report.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
         return -1;
     }
 
-    ret = sqlite3_bind_int(stmt, 6, mil_version);
+    ret = sqlite3_bind_int(stmt, 6, (int)compress);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
+
+    ret = sqlite3_bind_int(stmt, 7, mil_version);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
@@ -801,6 +863,7 @@ int SQLLiteReport::save_report(int user, long file_id, MediaConchLib::report rep
 }
 
 int SQLLiteReport::update_report(int, long file_id, MediaConchLib::report reportKind, MediaConchLib::format format,
+                                 const std::string& options,
                                  const std::string& report, MediaConchLib::compression compress,
                                  int mil_version, std::string& err)
 {
@@ -809,7 +872,8 @@ int SQLLiteReport::update_report(int, long file_id, MediaConchLib::report report
     reports.clear();
     create << "UPDATE MEDIACONCH_REPORT ";
     create << "SET REPORT = ?, COMPRESS = ?, MIL_VERSION = ? ";
-    create << "WHERE FILE_ID = ? AND TOOL = ? AND FORMAT = ?;";
+    create << "WHERE FILE_ID = ? AND TOOL = ? AND FORMAT = ? ";
+    create << "AND OPTIONS = ?;";
     query = create.str();
 
     if (prepare_v2(query, err) < 0)
@@ -857,6 +921,13 @@ int SQLLiteReport::update_report(int, long file_id, MediaConchLib::report report
         return -1;
     }
 
+    ret = sqlite3_bind_text(stmt, 7, options.c_str(), options.size(), SQLITE_STATIC);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
+
     return execute();
 }
 
@@ -886,7 +957,8 @@ int SQLLiteReport::remove_report(int user, long file_id, std::string& err)
     return execute();
 }
 
-void SQLLiteReport::get_report(int user, long file_id, MediaConchLib::report reportKind, MediaConchLib::format format,
+void SQLLiteReport::get_report(int user, long file_id, MediaConchLib::report report_kind,
+                               MediaConchLib::format format, const std::string& options,
                                std::string& report, MediaConchLib::compression& compress, std::string& err)
 {
     if (!file_id_match_user(user, file_id, err))
@@ -901,7 +973,8 @@ void SQLLiteReport::get_report(int user, long file_id, MediaConchLib::report rep
     create << "SELECT REPORT, COMPRESS FROM MEDIACONCH_REPORT WHERE ";
     create << "FILE_ID = ? ";
     create << "AND TOOL = ? ";
-    create << "AND FORMAT = ?;";
+    create << "AND FORMAT = ?";
+    create << "AND OPTIONS = ?;";
     query = create.str();
 
     if (prepare_v2(query, err) < 0)
@@ -914,7 +987,7 @@ void SQLLiteReport::get_report(int user, long file_id, MediaConchLib::report rep
         return;
     }
 
-    ret = sqlite3_bind_int(stmt, 2, (int)reportKind);
+    ret = sqlite3_bind_int(stmt, 2, (int)report_kind);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
@@ -928,6 +1001,13 @@ void SQLLiteReport::get_report(int user, long file_id, MediaConchLib::report rep
         return;
     }
 
+    ret = sqlite3_bind_text(stmt, 4, options.c_str(), options.size(), SQLITE_STATIC);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return;
+    }
+
     if (execute() < 0 || !reports.size())
     {
         err = error;
@@ -955,8 +1035,9 @@ void SQLLiteReport::get_report(int user, long file_id, MediaConchLib::report rep
     }
 }
 
-bool SQLLiteReport::report_is_registered(int user, long file_id, MediaConchLib::report reportKind,
-                                         MediaConchLib::format format, std::string& err)
+bool SQLLiteReport::report_is_registered(int user, long file_id, MediaConchLib::report report_kind,
+                                         MediaConchLib::format format, const std::string& options,
+                                         std::string& err)
 {
     if (!file_id_match_user(user, file_id, err))
     {
@@ -971,7 +1052,8 @@ bool SQLLiteReport::report_is_registered(int user, long file_id, MediaConchLib::
     create << "SELECT " << key << " FROM MEDIACONCH_REPORT WHERE ";
     create << "FILE_ID = ? ";
     create << "AND TOOL = ? ";
-    create << "AND FORMAT = ?;";
+    create << "AND FORMAT = ? ";
+    create << "AND OPTIONS = ?;";
     query = create.str();
 
     if (prepare_v2(query, err) < 0)
@@ -984,7 +1066,7 @@ bool SQLLiteReport::report_is_registered(int user, long file_id, MediaConchLib::
         return false;
     }
 
-    ret = sqlite3_bind_int(stmt, 2, (int)reportKind);
+    ret = sqlite3_bind_int(stmt, 2, (int)report_kind);
     if (ret != SQLITE_OK)
     {
         err = get_sqlite_error(ret);
@@ -998,6 +1080,13 @@ bool SQLLiteReport::report_is_registered(int user, long file_id, MediaConchLib::
         return false;
     }
 
+    ret = sqlite3_bind_text(stmt, 4, options.c_str(), options.size(), SQLITE_STATIC);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return false;
+    }
+
     if (execute())
     {
         err = error;
