@@ -38,7 +38,7 @@ public:
 
     // functions
     int add_file_to_list(const std::string& file, const std::string& path, int policy, int display,
-                         int verbosity, bool fixer, std::string& err);
+                         int verbosity, bool fixer, bool force, bool, std::string& err);
     void clear_files();
     FileRegistered* get_file_registered_from_file(const std::string& file);
     FileRegistered* get_file_registered_from_id(long id);
