@@ -83,6 +83,13 @@ $(document).ready(function() {
         resetSelectList('applyAllPolicy');
     });
 
+    // Scroll to the top of the results when page is changed
+    $('#result-table').on('page.dt', function() {
+        $('html, body').animate({
+            scrollTop: $('#checkerResults').offset().top
+        }, 200);
+    });
+
     // Keep popover open while hover on the popover content
     var popoverManualBinding = function(elem) {
         elem.on('mouseenter', function () {
@@ -133,6 +140,20 @@ function getDataFromForm(form) {
     return formValues;
 }
 
+// Based on https://stackoverflow.com/a/41629420
+function jumpToPageContainingResultId(id) {
+    result.draw(false);
+    var node = result.row('#result-' + id).node();
+    var page = Math.floor(
+        result.rows({
+            page: 'all',
+            order: 'current',
+            search: 'applied'
+        }).nodes().indexOf( node ) / result.page.info().length
+    );
+    result.page(page).draw(false);
+}
+
 function updateFileOrAddFile(sourceName, fileName, fileId, values) {
     var formValues = JSON.parse(values);
     if (!result.$('tr.fileId-' + fileId).length) {
@@ -170,7 +191,10 @@ function updateFile(fileId, formValues) {
 }
 
 function addFile(sourceName, fileName, fileId, formValues) {
-    node = result.row.add( [ '<span title="' + sourceName + '">' + truncateString(fileName, 28) + '</span>', '', '', '', '', '<span class="status-text">In queue</span><button type="button" class="btn btn-link result-close" title="Close result"><span class="glyphicon glyphicon-trash" aria-hidden="true"></span></button><button type="button" class="btn btn-link hidden" title="Reload result"><span class="glyphicon glyphicon-refresh" aria-hidden="true"></span></button>' ] ).node();
+    node = result.row.add( [ '<span title="' + sourceName + '">' + truncateString(fileName, 28) + '</span>',
+                             '', '', '', '',
+                             '<div><span class="status-text">In queue</span><button type="button" class="btn btn-link result-close" title="Close result"><span class="glyphicon glyphicon-trash" aria-hidden="true"></span></button> \
+                              <button type="button" class="btn btn-link result-reload hidden" title="Reload result"><span class="glyphicon glyphicon-refresh" aria-hidden="true"></span></button></div>' ] ).node();
 
     // Add id
     resultId = 'result-' + fileId;
@@ -200,6 +224,13 @@ function addFile(sourceName, fileName, fileId, formValues) {
         };
     });
 
+    // Reload button
+    $(node).find('.result-reload').click(node, function (e) {
+        var id = $(result.row(e.data).node()).data('fileId');
+        resetRow(id);
+        forceAnalyzeRequest(id);
+    });
+
     if ($('#checkerResultTitle .close').hasClass('hidden')) {
         $('#checkerResultTitle .close').removeClass('hidden');
         $('#checkerApplyAll').removeClass('hidden');
@@ -212,8 +243,50 @@ function addFile(sourceName, fileName, fileId, formValues) {
         policyCellEmptyWithModal(resultId, fileId)
 };
 
+function resetRow(id) {
+    resetStatusCell(id);
+    resetImplementationCell(id);
+    resetPolicyCell(id);
+    resetMediaInfoCell(id);
+    resetMediaTraceCell(id);
+
+    removeImplemModalIfExists(id);
+    removePolicyModalIfExists(id);
+    removeMediaInfoModalIfExists(id);
+    removeMediaTraceModalIfExists(id);
+};
+
+function forceAnalyzeRequest(id) {
+    if (WEBMACHINE == "WEB_MACHINE_KIT")
+    {
+        res = webpage.checker_force_analyze(id);
+        data = JSON.parse(res);
+        if (!data.error)
+        {
+            startWaitingLoop();
+            successMessage('File reloaded successfuly');
+        }
+        else
+            errorMessage(data.error);
+    }
+    else
+    {
+        webpage.checker_force_analyze(id, function(res) {
+            data = JSON.parse(res);
+            if (!data.error)
+            {
+                startWaitingLoop();
+                successMessage('File reloaded successfuly');
+            }
+            else
+                errorMessage(data.error);
+        });
+    }
+
+};
+
 function startWaitingLoop() {
-    result.draw();
+    result.draw(false);
     stopWaitingLoop();
     waitingLoop(100, 1000);
 }
@@ -351,6 +424,7 @@ function processCheckerStatusRequest(statusMulti) {
                         implementationCell(data, 'result-' + data.fileId, data.fileId);
                     });
                 }
+                policyCellEmptyWithModal(statusResultId, statusFileId);
             }
 
             // MediaInfo
@@ -379,11 +453,20 @@ function processCheckerStatusRequest(statusMulti) {
 function statusCellSuccess(nodeStatus) {
     nodeStatus.removeClass('info danger checkInProgress').addClass('success');
     nodeStatus.find('.status-text').html('<span class="glyphicon glyphicon-ok text-success" aria-hidden="true"></span> Analyzed');
+    nodeStatus.find('.result-reload').removeClass('hidden');
 };
 
 function statusCellError(nodeStatus) {
     nodeStatus.removeClass('info danger checkInProgress').addClass('danger');
     nodeStatus.find('.status-text').html('<span class="glyphicon glyphicon-remove text-danger" aria-hidden="true"></span> Error');
+    nodeStatus.find('.result-reload').removeClass('hidden');
+}
+
+function resetStatusCell(id) {
+    var nodeStatus = $(result.cell('#result-' + id, 5).node());
+    nodeStatus.removeClass().addClass('statusCell info');
+    nodeStatus.find('.status-text').html('In queue');
+    nodeStatus.find('.result-reload').addClass('hidden');
 }
 
 function implementationCell(data, resultId, fileId) {
@@ -398,7 +481,7 @@ function implementationCell(data, resultId, fileId) {
         implemResultText = '<span class="glyphicon glyphicon-remove text-danger" aria-hidden="true"></span> Not valid';
     }
 
-    result.cell(nodeCell, 1).data(implemResultText + '<p class="pull-right"><a href="#" data-toggle="modal" data-target="#modalConformance' + resultId + '" title="View implementation report"><span class="glyphicon glyphicon-eye-open implem-view" aria-hidden="true"></span></a><a href="#" class="implem-dld" data-target="#modalConformance' + resultId + '" title="Download implementation report"><span class="glyphicon glyphicon-download" aria-hidden="true"></span></a></p>');
+    result.cell(nodeCell, 1).data('<div>' + implemResultText + '<p class="pull-right"><a href="#" data-toggle="modal" data-target="#modalConformance' + resultId + '" title="View implementation report"><span class="glyphicon glyphicon-eye-open implem-view" aria-hidden="true"></span></a><a href="#" class="implem-dld" data-target="#modalConformance' + resultId + '" title="Download implementation report"><span class="glyphicon glyphicon-download" aria-hidden="true"></span></a></p></div>');
 
     nodeImplem.find('.implem-view').on('click', function(e) {
         e.preventDefault();
@@ -526,7 +609,7 @@ function policyCell(data, resultId, fileId)
     policyResultText += '<span title="' + nodeCell.data('policyName') + '">' + truncateString(nodeCell.data('policyName'), 20) + '</span>';
     policyResultText += '</span>';
 
-    result.cell(nodeCell, 2).data(policyResultText + '<p class="pull-right"><a href="#" data-toggle="modal" data-target="#modalPolicy' + resultId + '" title="View policy report"><span class="glyphicon glyphicon-eye-open policy-view" aria-hidden="true"></span></a><a href="#" class="policy-dld" data-target="#modalPolicy' + resultId + '" title="Download policy report"><span class="glyphicon glyphicon-download" aria-hidden="true"></span></a></p>');
+    result.cell(nodeCell, 2).data('<div>' + policyResultText + '<p class="pull-right"><a href="#" data-toggle="modal" data-target="#modalPolicy' + resultId + '" title="View policy report"><span class="glyphicon glyphicon-eye-open policy-view" aria-hidden="true"></span></a><a href="#" class="policy-dld" data-target="#modalPolicy' + resultId + '" title="Download policy report"><span class="glyphicon glyphicon-download" aria-hidden="true"></span></a></p></div>');
 
     policyModal(resultId, fileId);
 }
@@ -535,7 +618,7 @@ function policyCellEmptyWithModal(resultId, fileId)
 {
     nodePolicy = $(result.cell('#' + resultId, 2).node());
     nodePolicy.removeClass().addClass('info');
-    result.cell('#' + resultId, 2).data('<span class="policyResult">N/A</span><p class="pull-right"><a href="#" data-toggle="modal" data-target="#modalPolicy' + resultId + '" title="View policy report"><span class="glyphicon glyphicon-eye-open policy-view" aria-hidden="true"></span></a></p>');
+    result.cell('#' + resultId, 2).data('<div><span class="policyResult">N/A</span><p class="pull-right"><a href="#" data-toggle="modal" data-target="#modalPolicy' + resultId + '" title="View policy report"><span class="glyphicon glyphicon-eye-open policy-view" aria-hidden="true"></span></a></p></div>');
 
     policyModal(resultId, fileId);
 }
@@ -690,6 +773,18 @@ function removeImplemModalIfExists(fileId)
     }
 }
 
+function removeMediaInfoModalIfExists(fileId) {
+    if ($('#modalInforesult-' + fileId).length) {
+        $('#modalInforesult-' + fileId).remove();
+    }
+}
+
+function removeMediaTraceModalIfExists(fileId) {
+    if ($('#modalTraceresult-' + fileId).length) {
+        $('#modalTraceresult-' + fileId).remove();
+    }
+}
+
 function updatePolicyCell(fileId, policyId) {
     removePolicyModalIfExists(fileId);
 
@@ -725,6 +820,19 @@ function resetPolicyCell(fileId) {
     $(result.cell('#result-' + fileId, 2).node()).empty();
 }
 
+function resetImplementationCell(fileId) {
+    $(result.cell('#result-' + fileId, 1).node()).removeClass();
+    $(result.cell('#result-' + fileId, 1).node()).empty();
+}
+
+function resetMediaInfoCell(fileId) {
+    $(result.cell('#result-' + fileId, 3).node()).empty();
+}
+
+function resetMediaTraceCell(fileId) {
+    $(result.cell('#result-' + fileId, 4).node()).empty();
+}
+
 function mediaInfoCell(resultId, fileId)
 {
     nodeMI = $(result.cell('#' + resultId, 3).node());
@@ -1082,15 +1190,15 @@ function displayReport(elemId, dataReport)
     //     };
     // });
 
-    // // Display success message
-    // function successMessage(message) {
-    //     $('#checkerInfo div').html('<div class="alert alert-success alert-dismissible"><button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>' + message + '</div>');
-    // }
+    // Display success message
+    function successMessage(message) {
+        $('#checkerInfo div').html('<div class="alert alert-success alert-dismissible"><button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>' + message + '</div>');
+    }
 
-    // // Display error message
-    // function errorMessage(message) {
-    //     $('#checkerInfo div').html('<div class="alert alert-danger alert-dismissible"><button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>' + message + '</div>')
-    // }
+    // Display error message
+    function errorMessage(message) {
+        $('#checkerInfo div').html('<div class="alert alert-danger alert-dismissible"><button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>' + message + '</div>')
+    }
 
     // // Handle fail ajax response
     // function failResponse(jqXHR, formType) {
